"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@collectable/core");
const internals_1 = require("../internals");
function emptyWithNumericKeys(mutability) {
    return empty(core_1.numericCompare, mutability);
}
exports.emptyWithNumericKeys = emptyWithNumericKeys;
function emptyWithStringKeys(mutability) {
    return empty(core_1.stringCompare, mutability);
}
exports.emptyWithStringKeys = emptyWithStringKeys;
/**
 * Creates an empty tree. If no ComparatorFn function is supplied, keys are compared using logical less-than and
 * greater-than operations, which will generally only be suitable for numeric or string keys.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {ComparatorFn<K>} compare A comparison function, taking two keys, and returning a value less than 0 if the
 *                                  first key is smaller than the second, a value greater than 0 if the first key is
 *                                  greater than the second, or 0 if they're the same.
 * @param {boolean} [mutability] Indicates the desired mutability of the returned tree
 * @returns {RedBlackTreeStructure<K, V>} An empty tree
 */
function empty(compare, mutability) {
    return internals_1.createTree(compare, mutability);
}
exports.empty = empty;
/**
 * Determines whether the input argument is an instance of a Collectable.js RedBlackTree structure.
 *
 * @export
 * @param {RedBlackTreeStructure<K, V>} arg The input value to check
 * @returns {boolean} True if the input value is a RedBlackTree, otherwise false
 */
function isRedBlackTree(arg) {
    return internals_1.isRedBlackTree(arg);
}
exports.isRedBlackTree = isRedBlackTree;

//# sourceMappingURL=empty.js.map
