import { isUndefined } from '@collectable/core';
import { iterateFromFirst, iterateKeysFromFirst, iterateValuesFromFirst, size } from './index';
const NOMAP = () => { };
export function arrayFrom(arg, tree) {
    var map;
    if (isUndefined(tree)) {
        tree = arg;
        map = NOMAP;
    }
    else {
        map = arg;
    }
    var array = new Array(size(tree));
    var it = iterateFromFirst(tree);
    var i, entry;
    if (map === NOMAP) {
        for (i = 0; i < array.length; i++) {
            array[i] = it.next().value;
        }
    }
    else {
        for (i = 0; i < array.length; i++) {
            entry = it.next().value;
            array[i] = map(entry.value, entry.key, i);
        }
    }
    return array;
}
/**
 * Returns a value iterator; one for each entry in the tree. The iterator is guaranteed to iterate in the same order as
 * the corresponding entries in the tree.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTreeStructure<K, V>} tree The tree to read values from
 * @returns {IterableIterator<V>} An iterable iterator that will visit each value in the tree
 */
export function values(tree) {
    return iterateValuesFromFirst(tree);
}
/**
 * Returns a key iterator; one for each entry in the tree. The iterator is guaranteed to iterate in the same order as
 * the corresponding entries in the tree.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTreeStructure<K, V>} tree The tree to read values from
 * @returns {IterableIterator<K>} An iterable iterator that will visit each key in the tree
 */
export function keys(tree) {
    return iterateKeysFromFirst(tree);
}

//# sourceMappingURL=unwrap.js.map
