import { Mutation } from '@collectable/core';
import { Associative, ComparatorFn } from '@collectable/core';
import { RedBlackTreeStructure } from '../internals';
export declare function fromNumericKeys(keys: number[] | RedBlackTreeStructure<number, any> | Iterable<number>, mutability?: Mutation.PreferredContext): RedBlackTreeStructure<number>;
export declare function fromStringKeys(keys: string[] | RedBlackTreeStructure<string, any> | Iterable<string>, mutability?: Mutation.PreferredContext): RedBlackTreeStructure<string>;
export declare function fromKeys<K>(compare: ComparatorFn<K>, keys: K[] | RedBlackTreeStructure<K, any> | Iterable<K>, mutability?: Mutation.PreferredContext): RedBlackTreeStructure<K>;
export declare function fromPairsWithNumericKeys<V>(pairs: [number, V][] | Iterable<[number, V]>, mutability?: Mutation.PreferredContext): RedBlackTreeStructure<number, V>;
export declare function fromPairsWithStringKeys<V>(pairs: [string, V][] | Iterable<[string, V]>, mutability?: Mutation.PreferredContext): RedBlackTreeStructure<string, V>;
/**
 * Creates a new `RedBlackTree` from an array of key/value pairs (tuples). If no ComparatorFn function is supplied, keys
 * are compared using logical less-than and greater-than operations, which will generally only be suitable for numeric
 * or string keys.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {[K, V][]} pairs An array of pairs (tuples), each being a two-element array of [key, value]
 * @param {ComparatorFn<K>} compare A comparison function, taking two keys, and returning a value less than 0 if the
 *                                  first key is smaller than the second, a value greater than 0 if the first key is
 *                                  greater than the second, or 0 if they're the same.
 * @returns {RedBlackTreeStructure<K, V>} A tree populated with an entry for each pair in the input array
 */
export declare function fromPairs<K, V>(compare: ComparatorFn<K>, pairs: [K, V][] | Iterable<[K, V]>, mutability?: Mutation.PreferredContext): RedBlackTreeStructure<K, V>;
/**
 * Creates a new `RedBlackTree` from a plain input object. If no ComparatorFn function is supplied, keys are compared
 * using logical less-than and greater-than operations, which will generally only be suitable for numeric or string keys.
 *
 * @export
 * @template V The type of values in the tree
 * @param {Associative<V>} obj The input object from which to create a new tree
 * @param {ComparatorFn<any>} compare A comparison function, taking two keys, and returning a value less than 0 if the
 *                                      first key is smaller than the second, a value greater than 0 if the first key is
 *                                      greater than the second, or 0 if they're the same.
 * @returns {RedBlackTreeStructure<string, V>} A tree populated with the keys and values of the input object
 */
export declare function fromObject<V>(obj: Associative<V> | V[], mutability?: Mutation.PreferredContext): RedBlackTreeStructure<string, V>;
export declare function fromObject<V>(obj: Associative<V> | V[], compare?: ComparatorFn<string>, mutability?: Mutation.PreferredContext): RedBlackTreeStructure<string, V>;
