import { Mutation } from '@collectable/core';
import { RedBlackTreeStructure } from './RedBlackTree';
export declare class Node<K, V> implements Mutation.PersistentStructure {
    key: K;
    value: V;
    _red: boolean;
    _left: Node<K, V>;
    _right: Node<K, V>;
    _count: number;
    readonly '@@mctx': Mutation.Context;
    constructor(mctx: Mutation.Context, key: K, value: V, _red: boolean, _left: Node<K, V>, _right: Node<K, V>, _count: number);
    /** @internal */
    '@@clone'(mctx: Mutation.Context): Node<K, V>;
}
/** A read-only reference to an entry in a RedBlackTree instance. */
export declare type RedBlackTreeEntry<K, V = null> = {
    /** Read only. The hash key of this entry in the tree. */
    readonly key: K;
    /** Read/write. The value of this entry in the tree. */
    value: V;
};
export declare const enum BRANCH {
    NONE = 0,
    LEFT = 1,
    RIGHT = 2,
}
export declare const NONE: Node<any, any>;
export declare function createNode<K, V>(tree: RedBlackTreeStructure<K, V>, red: boolean, key: K, value: V): Node<K, V>;
export declare function isNone<K, V>(node: Node<K, V>): boolean;
export declare function editRightChild<K, V>(owner: Mutation.PersistentStructure, node: Node<K, V>): Node<K, V>;
export declare function editLeftChild<K, V>(owner: Mutation.PersistentStructure, node: Node<K, V>): Node<K, V>;
export declare function assignValue<K, V>(value: V, node: Node<K, V>): boolean;
